from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# MessageExtendedMedia - Layer 181
MessageExtendedMedia = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.MessageExtendedMedia,
            pydantic.Tag('MessageExtendedMedia')
        ],
        typing.Annotated[
            types.MessageExtendedMediaPreview,
            pydantic.Tag('MessageExtendedMediaPreview')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputReplyToMessage(BaseModel):
    """
    types.InputReplyToMessage
    ID: 0x22c0f6d5
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputReplyToMessage', 'InputReplyToMessage'] = pydantic.Field(
        'types.InputReplyToMessage',
        alias='_'
    )

    reply_to_msg_id: int
    top_msg_id: typing.Optional[int] = None
    reply_to_peer_id: typing.Optional["base.InputPeer"] = None
    quote_text: typing.Optional[str] = None
    quote_entities: typing.Optional[list["base.MessageEntity"]] = None
    quote_offset: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ExportChatlistInvite(BaseModel):
    """
    functions.chatlists.ExportChatlistInvite
    ID: 0x8472478e
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.chatlists.ExportChatlistInvite', 'ExportChatlistInvite'] = pydantic.Field(
        'functions.chatlists.ExportChatlistInvite',
        alias='_'
    )

    chatlist: "base.InputChatlist"
    title: str
    peers: list["base.InputPeer"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateChatParticipantAdmin(BaseModel):
    """
    types.UpdateChatParticipantAdmin
    ID: 0xd7ca61a2
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateChatParticipantAdmin', 'UpdateChatParticipantAdmin'] = pydantic.Field(
        'types.UpdateChatParticipantAdmin',
        alias='_'
    )

    chat_id: int
    user_id: int
    is_admin: bool
    version: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class DiscardCall(BaseModel):
    """
    functions.phone.DiscardCall
    ID: 0xb2cbc1c0
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.phone.DiscardCall', 'DiscardCall'] = pydantic.Field(
        'functions.phone.DiscardCall',
        alias='_'
    )

    peer: "base.InputPhoneCall"
    duration: int
    reason: "base.PhoneCallDiscardReason"
    connection_id: int
    video: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputBotAppID(BaseModel):
    """
    types.InputBotAppID
    ID: 0xa920bd7a
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputBotAppID', 'InputBotAppID'] = pydantic.Field(
        'types.InputBotAppID',
        alias='_'
    )

    id: int
    access_hash: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelAdminLogEventActionChangeProfilePeerColor(BaseModel):
    """
    types.ChannelAdminLogEventActionChangeProfilePeerColor
    ID: 0x5e477b25
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChannelAdminLogEventActionChangeProfilePeerColor', 'ChannelAdminLogEventActionChangeProfilePeerColor'] = pydantic.Field(
        'types.ChannelAdminLogEventActionChangeProfilePeerColor',
        alias='_'
    )

    prev_value: "base.PeerColor"
    new_value: "base.PeerColor"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SearchCounter(BaseModel):
    """
    types.messages.SearchCounter
    ID: 0xe844ebff
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.SearchCounter', 'SearchCounter'] = pydantic.Field(
        'types.messages.SearchCounter',
        alias='_'
    )

    filter: "base.MessagesFilter"
    count: int
    inexact: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageMediaDice(BaseModel):
    """
    types.MessageMediaDice
    ID: 0x3f7ee58b
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageMediaDice', 'MessageMediaDice'] = pydantic.Field(
        'types.MessageMediaDice',
        alias='_'
    )

    value: int
    emoticon: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PageBlockDetails(BaseModel):
    """
    types.PageBlockDetails
    ID: 0x76768bed
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PageBlockDetails', 'PageBlockDetails'] = pydantic.Field(
        'types.PageBlockDetails',
        alias='_'
    )

    blocks: list["base.PageBlock"]
    title: "base.RichText"
    open: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class EncryptedChat(BaseModel):
    """
    types.EncryptedChat
    ID: 0x61f0d4c7
    Layer: 181
    """
    QUALNAME: typing.Literal['types.EncryptedChat', 'EncryptedChat'] = pydantic.Field(
        'types.EncryptedChat',
        alias='_'
    )

    id: int
    access_hash: int
    date: Datetime
    admin_id: int
    participant_id: int
    g_a_or_b: Bytes
    key_fingerprint: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InviteToGroupCall(BaseModel):
    """
    functions.phone.InviteToGroupCall
    ID: 0x7b393160
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.phone.InviteToGroupCall', 'InviteToGroupCall'] = pydantic.Field(
        'functions.phone.InviteToGroupCall',
        alias='_'
    )

    call: "base.InputGroupCall"
    users: list["base.InputUser"]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# WebPageAttribute - Layer 181
WebPageAttribute = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.WebPageAttributeStickerSet,
            pydantic.Tag('WebPageAttributeStickerSet')
        ],
        typing.Annotated[
            types.WebPageAttributeStory,
            pydantic.Tag('WebPageAttributeStory')
        ],
        typing.Annotated[
            types.WebPageAttributeTheme,
            pydantic.Tag('WebPageAttributeTheme')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelAdminLogEventActionDefaultBannedRights(BaseModel):
    """
    types.ChannelAdminLogEventActionDefaultBannedRights
    ID: 0x2df5fc0a
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChannelAdminLogEventActionDefaultBannedRights', 'ChannelAdminLogEventActionDefaultBannedRights'] = pydantic.Field(
        'types.ChannelAdminLogEventActionDefaultBannedRights',
        alias='_'
    )

    prev_banned_rights: "base.ChatBannedRights"
    new_banned_rights: "base.ChatBannedRights"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UserStatusLastMonth(BaseModel):
    """
    types.UserStatusLastMonth
    ID: 0x65899777
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UserStatusLastMonth', 'UserStatusLastMonth'] = pydantic.Field(
        'types.UserStatusLastMonth',
        alias='_'
    )

    by_me: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Dialogs(BaseModel):
    """
    types.messages.Dialogs
    ID: 0x15ba6c40
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.Dialogs', 'Dialogs'] = pydantic.Field(
        'types.messages.Dialogs',
        alias='_'
    )

    dialogs: list["base.Dialog"]
    messages: list["base.Message"]
    chats: list["base.Chat"]
    users: list["base.User"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChatBannedRights(BaseModel):
    """
    types.ChatBannedRights
    ID: 0x9f120418
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChatBannedRights', 'ChatBannedRights'] = pydantic.Field(
        'types.ChatBannedRights',
        alias='_'
    )

    until_date: Datetime
    view_messages: typing.Optional[bool] = None
    send_messages: typing.Optional[bool] = None
    send_media: typing.Optional[bool] = None
    send_stickers: typing.Optional[bool] = None
    send_gifs: typing.Optional[bool] = None
    send_games: typing.Optional[bool] = None
    send_inline: typing.Optional[bool] = None
    embed_links: typing.Optional[bool] = None
    send_polls: typing.Optional[bool] = None
    change_info: typing.Optional[bool] = None
    invite_users: typing.Optional[bool] = None
    pin_messages: typing.Optional[bool] = None
    manage_topics: typing.Optional[bool] = None
    send_photos: typing.Optional[bool] = None
    send_videos: typing.Optional[bool] = None
    send_roundvideos: typing.Optional[bool] = None
    send_audios: typing.Optional[bool] = None
    send_voices: typing.Optional[bool] = None
    send_docs: typing.Optional[bool] = None
    send_plain: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageActionBotAllowed(BaseModel):
    """
    types.MessageActionBotAllowed
    ID: 0xc516d679
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageActionBotAllowed', 'MessageActionBotAllowed'] = pydantic.Field(
        'types.MessageActionBotAllowed',
        alias='_'
    )

    attach_menu: typing.Optional[bool] = None
    from_request: typing.Optional[bool] = None
    domain: typing.Optional[str] = None
    app: typing.Optional["base.BotApp"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BusinessIntro(BaseModel):
    """
    types.BusinessIntro
    ID: 0x5a0a066d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.BusinessIntro', 'BusinessIntro'] = pydantic.Field(
        'types.BusinessIntro',
        alias='_'
    )

    title: str
    description: str
    sticker: typing.Optional["base.Document"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateMessagePoll(BaseModel):
    """
    types.UpdateMessagePoll
    ID: 0xaca1657b
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateMessagePoll', 'UpdateMessagePoll'] = pydantic.Field(
        'types.UpdateMessagePoll',
        alias='_'
    )

    poll_id: int
    results: "base.PollResults"
    poll: typing.Optional["base.Poll"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AutoSaveSettings(BaseModel):
    """
    types.account.AutoSaveSettings
    ID: 0x4c3e069d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.account.AutoSaveSettings', 'AutoSaveSettings'] = pydantic.Field(
        'types.account.AutoSaveSettings',
        alias='_'
    )

    users_settings: "base.AutoSaveSettings"
    chats_settings: "base.AutoSaveSettings"
    broadcasts_settings: "base.AutoSaveSettings"
    exceptions: list["base.AutoSaveException"]
    chats: list["base.Chat"]
    users: list["base.User"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SentCode(BaseModel):
    """
    types.auth.SentCode
    ID: 0x5e002502
    Layer: 181
    """
    QUALNAME: typing.Literal['types.auth.SentCode', 'SentCode'] = pydantic.Field(
        'types.auth.SentCode',
        alias='_'
    )

    type: "base.auth.SentCodeType"
    phone_code_hash: str
    next_type: typing.Optional["base.auth.CodeType"] = None
    timeout: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# payments.PaymentForm - Layer 181
PaymentForm = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.payments.PaymentForm,
            pydantic.Tag('payments.PaymentForm'),
            pydantic.Tag('PaymentForm')
        ],
        typing.Annotated[
            types.payments.PaymentFormStars,
            pydantic.Tag('payments.PaymentFormStars'),
            pydantic.Tag('PaymentFormStars')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AcceptLoginToken(BaseModel):
    """
    functions.auth.AcceptLoginToken
    ID: 0xe894ad4d
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.auth.AcceptLoginToken', 'AcceptLoginToken'] = pydantic.Field(
        'functions.auth.AcceptLoginToken',
        alias='_'
    )

    token: Bytes



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# StarsTransactionPeer - Layer 181
StarsTransactionPeer = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.StarsTransactionPeer,
            pydantic.Tag('StarsTransactionPeer')
        ],
        typing.Annotated[
            types.StarsTransactionPeerAppStore,
            pydantic.Tag('StarsTransactionPeerAppStore')
        ],
        typing.Annotated[
            types.StarsTransactionPeerFragment,
            pydantic.Tag('StarsTransactionPeerFragment')
        ],
        typing.Annotated[
            types.StarsTransactionPeerPlayMarket,
            pydantic.Tag('StarsTransactionPeerPlayMarket')
        ],
        typing.Annotated[
            types.StarsTransactionPeerPremiumBot,
            pydantic.Tag('StarsTransactionPeerPremiumBot')
        ],
        typing.Annotated[
            types.StarsTransactionPeerUnsupported,
            pydantic.Tag('StarsTransactionPeerUnsupported')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateGroupCallParticipants(BaseModel):
    """
    types.UpdateGroupCallParticipants
    ID: 0xf2ebdb4e
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateGroupCallParticipants', 'UpdateGroupCallParticipants'] = pydantic.Field(
        'types.UpdateGroupCallParticipants',
        alias='_'
    )

    call: "base.InputGroupCall"
    participants: list["base.GroupCallParticipant"]
    version: int
